from ecosound.core.tools import filename_to_datetime

file_1 = r'\\stellwagen.nefsc.noaa.gov\stellwagen\ACOUSTIC_DATA\BOTTOM_MOUNTED\NEFSC_SBNMS\NEFSC_SBNMS_202103_SB01\67403784_48kHz\SanctSound_SB01_15_67403784_20210324_223239.wav'
file_2 = r'\\stellwagen.nefsc.noaa.gov\stellwagen\ACOUSTIC_DATA\BOTTOM_MOUNTED\NEFSC_SBNMS\NEFSC_SBNMS_200606\NEFSC_SBNMS_200606_EST\20060629\SNMS_20060629_023000.aif'
file_3 = r'\\stellwagen.nefsc.noaa.gov\stellwagen\ACOUSTIC_DATA\BOTTOM_MOUNTED\JASCO_DE\JASCO_DE_201006\MMS_Dep1_Delaware-e1d282a3.e1d282a3.Chan_1-24bps.1277236867.2010-06-22-20-01-07.wav'
file_4 = r'\\stellwagen.nefsc.noaa.gov\stellwagen\ACOUSTIC_DATA\BOTTOM_MOUNTED\NEFSC_MA-RI\NEFSC_MA-RI_202202_NS01\NEFSC_MA-RI_202202_NS01_ST\6075_64kHz_UTC\6075.220210084905.wav'
file_5 = r'\\stellwagen.nefsc.noaa.gov\stellwagen\PAM_20171108_094819_000.wav'
file_6 = r'\\stellwagen.nefsc.noaa.gov\stellwagen\WAT_NC_03_170716_180000_df100.x'
file_7 = r'\\stellwagen.nefsc.noaa.gov\stellwagen\SanctSound_SB01_01_1678032935_181112190000.wav'
file_8 = r'\\stellwagen.nefsc.noaa.gov\stellwagen\Brunswick04_002K_M06_multi_UTCm5_20170528_110000.aif'
file_9 = r'\\stellwagen.nefsc.noaa.gov\stellwagen\NRS08-140523-001620.wav'


print(filename_to_datetime(file_1))
print(filename_to_datetime(file_2))
print(filename_to_datetime(file_3))
print(filename_to_datetime(file_4))
print(filename_to_datetime(file_5))
print(filename_to_datetime(file_6))
print(filename_to_datetime(file_7))
print(filename_to_datetime(file_8))
print(filename_to_datetime(file_9))



# -*- coding: utf-8 -*-
"""
Created on Tue Nov  8 10:55:51 2022

@author: xavier.mouy
"""

from ecosound.core.annotation import Annotation
from ecosound.core.measurement import Measurement
from ecosound.measurements.measurer_builder import MeasurerFactory
from ecosound.core.audiotools import Sound
import os
import numpy as np

annot_file = r"D:\NOAA\2022_BC_fish_detector\manual_annotations\Master_annotations_dataset_20221028_without_06-MILL-FS.nc"
annot_file2 = r"D:\NOAA\2022_BC_fish_detector\manual_annotations\Master_annotations_dataset_20221028_without_06-MILL-FS_withSNR.nc"
noise_win_sec = "auto"  # 0.25

# load annotations
dataset = Annotation()
dataset.from_netcdf(annot_file)

# filter
# dataset.filter('label_class=="FS"', inplace=True)
# dataset.data = dataset.data.iloc[:100]
# dataset.update_audio_dir(r"D:\NOAA\2022_BC_fish_detector\manual_annotations")
dataset.data.drop([0,1,2])


# Meausrement
snr_measurer = MeasurerFactory("SNR", noise_win_sec=noise_win_sec)
measurements_snr = snr_measurer.compute(dataset, verbose=True)
measurements_snr.to_netcdf(annot_file2)
print("done")



# -*- coding: utf-8 -*-
"""
Created on Wed Jun 22 13:35:34 2022

@author: xavier.mouy
"""

import sys
sys.path.append(r"C:\Users\xavier.mouy\Documents\GitHub\ecosound") # Adds higher directory to python modules path.
from ecosound.core.annotation import Annotation

#infile = r'C:\Users\xavier.mouy\Documents\GitHub\ecosound\data\sqlite_annotations'
infile = r'C:\Users\xavier.mouy\Documents\GitHub\ecosound\data\sqlite_annotations/read/detections1.sqlite'
#infile = [r'C:\Users\xavier.mouy\Documents\GitHub\ecosound\data\sqlite_annotations/read/detections1.sqlite',r'C:\Users\xavier.mouy\Documents\GitHub\ecosound\data\sqlite_annotations/read/detections2.sqlite']

# load sqlite tables
annot = Annotation()
annot.from_sqlite(infile, verbose=True)


# write sqlite table
outfile =r'C:\Users\xavier.mouy\Documents\GitHub\ecosound\data\sqlite_annotations/write/detections3.sqlite'
annot.to_sqlite(outfile)

# load created sqlite tables
annot2 = Annotation()
annot2.from_sqlite(outfile, verbose=True)

agg_1D = annot2.calc_time_aggregate_1D(integration_time='1H',is_binary=True) 
agg_2D = annot2.calc_time_aggregate_2D(integration_time='1H',is_binary=False)